@@ -12,15 +12,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import List, Dict, Optional, Tuple, Callable, Union
 import json
+from typing import Optional
 
 from cortex.client import Client
 from cortex.binary import run_cli
+from cortex.telemetry import sentry_wrapper
 from cortex.exceptions import NotFound
 
 
-def client(env: str) -> Client:
+@sentry_wrapper
+def client(env: Optional[str] = None) -> Client:
     """
     Initialize a client based on the specified environment.
 
@@ -32,19 +34,23 @@ def client(env: str) -> Client:
     """
     environments = env_list()
 
-    found = False
+    if env is None:
+        if not environments["default_environment"]:
+            raise NotFound("no default environment configured")
+        env = environments["default_environment"]
 
-    for environment in environments:
+    found = False
+    for environment in environments["environments"]:
         if environment["name"] == env:
             found = True
             break
-
     if not found:
         raise NotFound(f"can't find environment {env}, create one by calling `cortex.new_client()`")
 
     return Client(environment)
 
 
+@sentry_wrapper
 def new_client(
     name: str,
     operator_endpoint: str,
@@ -72,6 +78,7 @@ def new_client(
     return client(name)
 
 
+@sentry_wrapper
 def env_list() -> list:
     """
     List all environments configured on this machine.
@@ -80,6 +87,7 @@ def env_list() -> list:
     return json.loads(output.strip())
 
 
+@sentry_wrapper
 def env_delete(name: str):
     """
     Delete an environment configured on this machine.
