@@ -25,22 +25,16 @@ import inspect
 import shutil
 from pathlib import Path
 
-from typing import List, Dict, Optional, Tuple, Callable, Union
+from typing import Optional
+
 from cortex.binary import run_cli, get_cli_path
+from cortex.telemetry import sentry_wrapper
+from cortex.consts import EXPECTED_PYTHON_VERSION
 from cortex import util
 
-# Change if PYTHONVERSION changes
-EXPECTED_PYTHON_VERSION = "3.6.9"
-
-
-def cli_config_dir() -> Path:
-    cli_config_dir = os.environ.get("CORTEX_CLI_CONFIG_DIR", "")
-    if cli_config_dir == "":
-        return Path.home() / ".cortex"
-    return Path(cli_config_dir).expanduser().resolve()
-
 
 class Client:
+    @sentry_wrapper
     def __init__(self, env: dict):
         """
         A client to deploy and manage APIs in the specified environment.
@@ -48,10 +42,12 @@ class Client:
         Args:
             env: Environment config
         """
+
         self.env = env
         self.env_name = env["name"]
 
     # CORTEX_VERSION_MINOR
+    @sentry_wrapper
     def create_api(
         self,
         api_spec: dict,
@@ -67,7 +63,7 @@ class Client:
         Deploy an API.
 
         Args:
-            api_spec: A dictionary defining a single Cortex API. See https://docs.cortex.dev/v/0.29/ for schema.
+            api_spec: A dictionary defining a single Cortex API. See https://docs.cortex.dev/v/0.31/ for schema.
             predictor: A Cortex Predictor class implementation. Not required for TaskAPI/TrafficSplitter kinds.
             task: A callable class/function implementation. Not required for RealtimeAPI/BatchAPI/TrafficSplitter kinds.
             requirements: A list of PyPI dependencies that will be installed before the predictor class implementation is invoked.
@@ -126,7 +122,7 @@ class Client:
         if api_spec.get("name") is None:
             raise ValueError("`api_spec` must have the `name` key set")
 
-        project_dir = cli_config_dir() / "deployments" / api_spec["name"]
+        project_dir = util.cli_config_dir() / "deployments" / api_spec["name"]
 
         if project_dir.exists():
             shutil.rmtree(str(project_dir))
@@ -236,14 +232,14 @@ class Client:
             "--env",
             self.env_name,
             "-o",
-            "mixed",
+            "json",
             "-y",
         ]
 
         if force:
             args.append("--force")
 
-        output = run_cli(args, mixed_output=True)
+        output = run_cli(args, hide_output=True)
 
         deploy_results = json.loads(output.strip())
 
@@ -290,6 +286,7 @@ class Client:
 
         return api
 
+    @sentry_wrapper
     def get_api(self, api_name: str) -> dict:
         """
         Get information about an API.
@@ -305,6 +302,7 @@ class Client:
         apis = json.loads(output.strip())
         return apis[0]
 
+    @sentry_wrapper
     def list_apis(self) -> list:
         """
         List all APIs in the environment.
@@ -318,6 +316,7 @@ class Client:
 
         return json.loads(output.strip())
 
+    @sentry_wrapper
     def get_job(self, api_name: str, job_id: str) -> dict:
         """
         Get information about a submitted job.
@@ -335,6 +334,7 @@ class Client:
 
         return json.loads(output.strip())
 
+    @sentry_wrapper
     def refresh(self, api_name: str, force: bool = False):
         """
         Restart all of the replicas for a Realtime API without downtime.
@@ -350,6 +350,7 @@ class Client:
 
         run_cli(args, hide_output=True)
 
+    @sentry_wrapper
     def patch(self, api_spec: dict, force: bool = False) -> dict:
         """
         Update the api specification for an API that has already been deployed.
@@ -359,7 +360,9 @@ class Client:
             force: Override an already in-progress API update.
         """
 
-        cortex_yaml_file = cli_config_dir() / "deployments" / f"cortex-{str(uuid.uuid4())}.yaml"
+        cortex_yaml_file = (
+            util.cli_config_dir() / "deployments" / f"cortex-{str(uuid.uuid4())}.yaml"
+        )
         with util.open_temporarily(cortex_yaml_file, "w") as f:
             yaml.dump([api_spec], f)
             args = ["patch", cortex_yaml_file, "--env", self.env_name, "-o", "json"]
@@ -370,6 +373,7 @@ class Client:
             output = run_cli(args, hide_output=True)
             return json.loads(output.strip())
 
+    @sentry_wrapper
     def delete_api(self, api_name: str, keep_cache: bool = False):
         """
         Delete an API.
@@ -393,6 +397,7 @@ class Client:
 
         run_cli(args, hide_output=True)
 
+    @sentry_wrapper
     def stop_job(self, api_name: str, job_id: str, keep_cache: bool = False):
         """
         Stop a running job.
@@ -413,6 +418,7 @@ class Client:
 
         run_cli(args)
 
+    @sentry_wrapper
     def stream_api_logs(
         self,
         api_name: str,
@@ -426,6 +432,7 @@ class Client:
         args = ["logs", api_name, "--env", self.env_name, "-y"]
         run_cli(args)
 
+    @sentry_wrapper
     def stream_job_logs(
         self,
         api_name: str,
